package core

import (
	"encoding/json"
	"github.com/louisevanderlith/husk"
	"github.com/louisevanderlith/husk/collections"
	"os"
	"reflect"
)

type VehicleContext interface {
	GetManufacturers(year int) (map[string]struct{}, error)
	GetModels(year int, manufacturer string) (map[string]struct{}, error)
	GetTrims(year int, manufacturer, model string) (map[string]struct{}, error)
}

func GetManufacturers(year int) (map[string]struct{}, error) {
	result := make(map[string]struct{})
	err := ctx.Vehicles.Map(&result, Manufacturers(year))

	if err != nil {
		return nil, err
	}

	return result, nil
}

func GetModels(year int, manufacturer string) (map[string]struct{}, error) {
	result := make(map[string]struct{})
	err := ctx.Vehicles.Map(&result, Models(year, manufacturer))

	if err != nil {
		return nil, err
	}

	return result, nil
}

func GetTrims(year int, manufacturer, model string) (map[string]struct{}, error) {
	result := make(map[string]struct{})
	err := ctx.Vehicles.Map(&result, Trim(year, manufacturer, model))

	if err != nil {
		return nil, err
	}

	return result, nil
}

type context struct {
	Vehicles husk.Table
}

var ctx context

func CreateContext() {
	defer seed()
	ctx = context{
		Vehicles: husk.NewTable(Vehicle{}),
	}
}

func seed() {
	//profiles, err := vehicleSeed()
	profiles, err := ScrapeCars()

	if err != nil {
		panic(err)
	}

	err = ctx.Vehicles.Seed(profiles)

	if err != nil {
		panic(err)
	}
}

func vehicleSeed() (collections.Enumerable, error) {
	f, err := os.Open("db/vehicles.seed.json")

	if err != nil {
		return nil, err
	}

	var items []Vehicle
	dec := json.NewDecoder(f)
	err = dec.Decode(&items)

	if err != nil {
		return nil, err
	}

	return collections.ReadOnlyList(reflect.ValueOf(items)), nil
}

func Shutdown() {
	ctx.Vehicles.Save()
}
